/*
 *  gstutils_version.h - GStreamer version utilities
 *
 *  Copyright (C) 2011 Intel Corporation
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public License
 *  as published by the Free Software Foundation; either version 2.1
 *  of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301 USA
 */

#ifndef GST_UTILS_VERSION_H
#define GST_UTILS_VERSION_H

/* gst-plugins-base version */
#define GST_PLUGINS_BASE_MAJOR_VERSION 0
#define GST_PLUGINS_BASE_MINOR_VERSION 10
#define GST_PLUGINS_BASE_MICRO_VERSION 36

/**
 * GST_UTILS_CHECK_VERSION:
 * @major: major version, like 1 in 1.2.3
 * @minor: minor version, like 2 in 1.2.3
 * @micro: micro version, like 3 in 1.2.3
 *
 * Evaluates to %TRUE if the version of gst-plugins-base is equal or
 * greater than @major, @minor and @micro
 */
#define GST_UTILS_CHECK_VERSION(major,minor,micro, rmajor,rminor,rmicro) \
    ((rmajor) > (major) ||                                              \
     ((rmajor) == (major) && (rminor) > (minor)) ||                     \
     ((rmajor) == (major) && (rminor) == (minor) && (rmicro) >= (micro)))

/**
 * GST_PLUGINS_BASE_CHECK_VERSION:
 * @major: major version, like 1 in 1.2.3
 * @minor: minor version, like 2 in 1.2.3
 * @micro: micro version, like 3 in 1.2.3
 *
 * Evaluates to %TRUE if the version of gst-plugins-base is greater
 * than @major, @minor and @micro
 */
#ifndef GST_PLUGINS_BASE_CHECK_VERSION
#define GST_PLUGINS_BASE_CHECK_VERSION(major,minor,micro)       \
    GST_UTILS_CHECK_VERSION(major,minor,micro,                  \
                            GST_PLUGINS_BASE_MAJOR_VERSION,     \
                            GST_PLUGINS_BASE_MINOR_VERSION,     \
                            GST_PLUGINS_BASE_MICRO_VERSION)
#endif

#endif /* GST_UTILS_VERSION_H */
